@@ -55,8 +55,8 @@ public:
     void reloadUoidList();
 
     QList<uint> mUoidList;
-    IdentityManager *mIdentityManager;
-    IdentityCombo *q;
+    IdentityManager *mIdentityManager = nullptr;
+    IdentityCombo *q = nullptr;
 };
 
 void KIdentityManagement::IdentityComboPrivate::reloadCombo()
@@ -81,15 +81,15 @@ void KIdentityManagement::IdentityComboPrivate::reloadUoidList()
 //@endcond
 
 IdentityCombo::IdentityCombo(IdentityManager *manager, QWidget *parent)
-    : KComboBox(parent)
+    : QComboBox(parent)
     , d(new IdentityComboPrivate(manager, this))
 {
     d->reloadCombo();
     d->reloadUoidList();
-    connect(this, static_cast<void (IdentityCombo::*)(int)>(&IdentityCombo::activated), this, &IdentityCombo::slotEmitChanged);
+    connect(this, QOverload<int>::of(&IdentityCombo::activated), this, &IdentityCombo::slotEmitChanged);
     connect(this, &IdentityCombo::identityChanged, this, &IdentityCombo::slotUpdateTooltip);
-    connect(manager, SIGNAL(changed()),
-            SLOT(slotIdentityManagerChanged()));
+    connect(manager, QOverload<>::of(&IdentityManager::changed), this, &IdentityCombo::slotIdentityManagerChanged);
+    connect(manager, &IdentityManager::deleted, this, &IdentityCombo::identityDeleted);
     slotUpdateTooltip(currentIdentity());
 }
 
