@@ -29,7 +29,6 @@
 #include <ktoolbar.h>
 #include <krun.h>
 #include <QUrl>
-#include <KComboBox>
 
 #include <KPIMTextEdit/RichTextComposer>
 #include <KPIMTextEdit/RichTextComposerImages>
@@ -39,7 +38,7 @@
 #include <QDir>
 #include <QFileInfo>
 #include <QLabel>
-
+#include <QComboBox>
 #include <QStackedWidget>
 
 #include <QVBoxLayout>
@@ -52,9 +51,7 @@
 
 using namespace KIdentityManagement;
 
-namespace KIdentityManagement
-{
-
+namespace KIdentityManagement {
 /**
    Private class that helps to provide binary compatibility between releases.
    @internal
@@ -70,23 +67,23 @@ public:
     QString asCleanedHTML() const;
 
     SignatureConfigurator *q;
-    bool inlinedHtml;
+    bool inlinedHtml = false;
     QString imageLocation;
-    QCheckBox        *mEnableCheck;
-    QCheckBox        *mHtmlCheck;
-    KComboBox        *mSourceCombo;
-    KUrlRequester    *mFileRequester;
-    QPushButton      *mEditButton;
-    KLineEdit        *mCommandEdit;
-    KToolBar         *mEditToolBar;
-    KToolBar         *mFormatToolBar;
-    KPIMTextEdit::RichTextComposer *mTextEdit;
-
+    QCheckBox *mEnableCheck = nullptr;
+    QCheckBox *mHtmlCheck = nullptr;
+    QComboBox *mSourceCombo = nullptr;
+    KUrlRequester *mFileRequester = nullptr;
+    QPushButton *mEditButton = nullptr;
+    KLineEdit *mCommandEdit = nullptr;
+    KToolBar *mEditToolBar = nullptr;
+    KToolBar *mFormatToolBar = nullptr;
+    KPIMTextEdit::RichTextComposer *mTextEdit = nullptr;
 };
 //@endcond
 
 SignatureConfigurator::Private::Private(SignatureConfigurator *parent)
-    : q(parent), inlinedHtml(true)
+    : q(parent)
+    , inlinedHtml(true)
 {
 }
 
@@ -108,14 +105,7 @@ QString SignatureConfigurator::Private::asCleanedHTML() const
 
 void SignatureConfigurator::Private::init()
 {
-    // tmp. vars:
-    QLabel *label;
-    QWidget *page;
-    QHBoxLayout *hlay;
-    QVBoxLayout *vlay;
-    QVBoxLayout *page_vlay;
-
-    vlay = new QVBoxLayout(q);
+    QVBoxLayout *vlay = new QVBoxLayout(q);
     vlay->setObjectName(QStringLiteral("main layout"));
 
     // "enable signatue" checkbox:
@@ -126,9 +116,9 @@ void SignatureConfigurator::Private::init()
     vlay->addWidget(mEnableCheck);
 
     // "obtain signature text from" combo and label:
-    hlay = new QHBoxLayout(); // inherits spacing
+    QHBoxLayout *hlay = new QHBoxLayout(); // inherits spacing
     vlay->addLayout(hlay);
-    mSourceCombo = new KComboBox(q);
+    mSourceCombo = new QComboBox(q);
     mSourceCombo->setEditable(false);
     mSourceCombo->setWhatsThis(
         i18n("Click on the widgets below to obtain help on the input methods."));
@@ -140,7 +130,7 @@ void SignatureConfigurator::Private::init()
                                     "File")
                            << i18nc("continuation of \"obtain signature text from\"",
                                     "Output of Command"));
-    label = new QLabel(i18n("Obtain signature &text from:"), q);
+    QLabel *label = new QLabel(i18n("Obtain signature &text from:"), q);
     label->setBuddy(mSourceCombo);
     label->setEnabled(false);   // since !mEnableCheck->isChecked()
     hlay->addWidget(label);
@@ -150,22 +140,21 @@ void SignatureConfigurator::Private::init()
     QStackedWidget *widgetStack = new QStackedWidget(q);
     widgetStack->setEnabled(false);   // since !mEnableCheck->isChecked()
     vlay->addWidget(widgetStack, 1);
-    q->connect(mSourceCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
-    q->connect(mSourceCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::highlighted), widgetStack, &QStackedWidget::setCurrentIndex);
+    q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::currentIndexChanged), widgetStack, &QStackedWidget::setCurrentIndex);
+    q->connect(mSourceCombo, QOverload<int>::of(&QComboBox::highlighted), widgetStack, &QStackedWidget::setCurrentIndex);
     // connects for the enabling of the widgets depending on
     // signatureEnabled:
-    q->connect(mEnableCheck, &QCheckBox::toggled, mSourceCombo, &KComboBox::setEnabled);
+    q->connect(mEnableCheck, &QCheckBox::toggled, mSourceCombo, &QComboBox::setEnabled);
     q->connect(mEnableCheck, &QCheckBox::toggled, widgetStack, &QStackedWidget::setEnabled);
     q->connect(mEnableCheck, &QCheckBox::toggled, label, &QLabel::setEnabled);
     // The focus might be still in the widget that is disabled
-    q->connect(mEnableCheck, SIGNAL(clicked()),
-               mEnableCheck, SLOT(setFocus()));
+    q->connect(mEnableCheck, &QCheckBox::clicked, mEnableCheck, QOverload<>::of(&QCheckBox::setFocus));
 
     int pageno = 0;
     // page 0: input field for direct entering:
-    page = new QWidget(widgetStack);
+    QWidget *page = new QWidget(widgetStack);
     widgetStack->insertWidget(pageno, page);
-    page_vlay = new QVBoxLayout(page);
+    QVBoxLayout *page_vlay = new QVBoxLayout(page);
     page_vlay->setMargin(0);
 
 #ifndef QT_NO_TOOLBAR
@@ -283,7 +272,8 @@ void SignatureConfigurator::Private::init()
 }
 
 SignatureConfigurator::SignatureConfigurator(QWidget *parent)
-    : QWidget(parent), d(new Private(this))
+    : QWidget(parent)
+    , d(new Private(this))
 {
     d->init();
 }
@@ -306,10 +296,14 @@ void SignatureConfigurator::setSignatureEnabled(bool enable)
 Signature::Type SignatureConfigurator::signatureType() const
 {
     switch (d->mSourceCombo->currentIndex()) {
-    case 0:  return Signature::Inlined;
-    case 1:  return Signature::FromFile;
-    case 2:  return Signature::FromCommand;
-    default: return Signature::Disabled;
+    case 0:
+        return Signature::Inlined;
+    case 1:
+        return Signature::FromFile;
+    case 2:
+        return Signature::FromCommand;
+    default:
+        return Signature::Disabled;
     }
 }
 
@@ -317,11 +311,19 @@ void SignatureConfigurator::setSignatureType(Signature::Type type)
 {
     int idx = 0;
     switch (type) {
-    case Signature::Inlined:     idx = 0; break;
-    case Signature::FromFile:    idx = 1; break;
-    case Signature::FromCommand: idx = 2; break;
-    default:                     idx = 0; break;
-    };
+    case Signature::Inlined:
+        idx = 0;
+        break;
+    case Signature::FromFile:
+        idx = 1;
+        break;
+    case Signature::FromCommand:
+        idx = 2;
+        break;
+    default:
+        idx = 0;
+        break;
+    }
 
     d->mSourceCombo->setCurrentIndex(idx);
 }
@@ -431,7 +433,9 @@ void SignatureConfigurator::slotEdit()
     // slotEnableEditButton should prevent this assert from being hit:
     assert(!url.isEmpty());
 
-    (void)KRun::runUrl(QUrl::fromLocalFile(url), QStringLiteral("text/plain"), this);
+    KRun::RunFlags flags;
+    flags |= KRun::DeleteTemporaryFiles;
+    KRun::runUrl(QUrl::fromLocalFile(url), QStringLiteral("text/plain"), this, flags);
 }
 
 // "use HTML"-checkbox (un)checked
@@ -468,10 +472,8 @@ void SignatureConfigurator::setImageLocation(const QString &path)
 void SignatureConfigurator::setImageLocation(const Identity &identity)
 {
     const QString dir = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + QStringLiteral("emailidentities/%1/").arg(
-                            QString::number(identity.uoid()));
+        QString::number(identity.uoid()));
     QDir().mkpath(dir);
     setImageLocation(dir);
 }
-
 }
-
